@@ -48,7 +48,6 @@ extern "C" {
 #else  /* __BORLANDC__ */
 
 #if defined(__EGC__) || defined(__GNUC__)
- #define NATIVE_ACCESS
  #if defined(__MINGW32__) || defined(__MINGW64__)
   #include <basetsd.h>
  #endif
@@ -65,6 +64,10 @@ extern "C" {
   #endif
  #endif
 
+ #ifndef HI_ENDIAN
+  #define NATIVE_ACCESS
+ #endif
+
  #if !defined(_ASM_GENERIC_INT_LL64_H) && !defined(_UAPI_ASM_GENERIC_INT_LL64_H)
   typedef int __s8 __attribute__((mode(QI)));
   typedef unsigned int __u8 __attribute__((mode(QI)));
@@ -83,8 +86,13 @@ extern "C" {
  #define __u64_defined
 
  #if __GNUC__>4 || (__GNUC__==4 && __GNUC_MINOR__>=3)
+  #define LD_UINT16_SWAP(ptr)  __builtin_bswap16((__u16)(*(__u16*)(__u8*)(ptr)))
   #define LD_UINT32_SWAP(ptr)  __builtin_bswap32((__u32)(*(__u32*)(__u8*)(ptr)))
   #define LD_UINT64_SWAP(ptr)  __builtin_bswap64((__u64)(*(__u64*)(__u8*)(ptr)))
+
+  #define ST_UINT16_SWAP(ptr,val)  *(__u16*)(__u8*)(ptr)=__builtin_bswap16((__u16)(val))
+  #define ST_UINT32_SWAP(ptr,val)  *(__u32*)(__u8*)(ptr)=__builtin_bswap32((__u32)(val))
+  #define ST_UINT64_SWAP(ptr,val)  *(__u64*)(__u8*)(ptr)=__builtin_bswap64((__u64)(val))
  #endif
 
 #else  /* __EGC__ || __GNUC__ */
@@ -230,17 +238,18 @@ extern "C" {
    typedef __u32  UINT32;
 #endif
 
+/*----------- END of per compiler section ------------*/
+
 
 #define LD_UINT16_CPU(ptr)	(__u16)(*(PACKED_PTR __u16*)(__u8*)(ptr))
+#define ST_UINT16_CPU(ptr,val)	*(PACKED_PTR __u16*)(__u8*)(ptr)=(__u16)(val)
+
 #define LD_UINT32_CPU(ptr)	(__u32)(*(PACKED_PTR UINT32*)(__u8*)(ptr))
+#define ST_UINT32_CPU(ptr,val)	*(PACKED_PTR UINT32*)(__u8*)(ptr)=(__u32)(val)
+
 #if defined(__u64_defined)
  #define LD_UINT64_CPU(ptr)	(__u64)(*(PACKED_PTR UINT64*)(__u8*)(ptr))
-#endif
-
-#define ST_UINT16_CPU(ptr,val)	*(PACKED_PTR __u16*)(__u8*)(ptr)=(__u16)(val)
-#define ST_UINT32_CPU(ptr,val)	*(PACKED_PTR UINT32*)(__u8*)(ptr)=(__u32)(val)
-#if defined(__u64_defined)
- #define ST_UINT64_CPU(ptr,val)	*(PACKED_PTR UINT64*)(__u8*)(ptr)=(__u64)(val)
+ #define ST_UINT64_CPU(ptr,val) *(PACKED_PTR UINT64*)(__u8*)(ptr)=(__u64)(val)
 #endif
 
 
@@ -255,6 +264,7 @@ void ST_FLOAT_SWAP(void *b, float f);
 
 
 #ifdef NATIVE_ACCESS  /* Enable word access to structures. */
+
  #ifdef LO_ENDIAN
   #define LD_UINT16_LO(ptr)	LD_UINT16_CPU(ptr)
   #define LD_UINT32_LO(ptr)	LD_UINT32_CPU(ptr)
@@ -295,13 +305,23 @@ void ST_FLOAT_SWAP(void *b, float f);
    #define LD_UINT64_HI(ptr)	LD_UINT64_CPU(ptr)
    #define ST_UINT64_HI(ptr,val) ST_UINT64_CPU(ptr,val)
   #endif
+
+  #define LD_UINT16_LO(ptr)	LD_UINT16_SWAP(ptr)
+  #define LD_UINT32_LO(ptr)	LD_UINT32_SWAP(ptr)
+  #define ST_UINT16_LO(ptr,val)	ST_UINT16_SWAP(ptr,val)
+  #define ST_UINT32_LO(ptr,val)	ST_UINT32_SWAP(ptr,val)
+  #if defined(__u64_defined)
+   #define LD_UINT64_LO(ptr)	LD_UINT64_SWAP(ptr)
+   #define ST_UINT64_LO(ptr,val) ST_UINT64_SWAP(ptr,val)
+  #endif
+
   #define LD_FLOAT_HI(ptr)	LD_UINT32_CPU(ptr)
   #define LD_FLOAT_LO(ptr)	LD_FLOAT_SWAP(ptr)
  #endif
 #endif
 
 
-/* Safe replacements for non native access. */
+	/* Safe replacements for non native access. */
 #ifndef LD_UINT16_LO
  #define LD_UINT16_LO(ptr)	(__u16)(((__u16)*(__u8*)((ptr)+1)<<8)|(__u16)*(__u8*)(ptr))
 #endif
@@ -317,7 +337,7 @@ void ST_FLOAT_SWAP(void *b, float f);
 
 #if defined(__u64_defined)
  #ifndef LD_UINT64_LO
-  #define LD_UINT64_LO(ptr)	(__u64)((((__u64)*(__u8*)((ptr)+7)<<56) | (((__u64)*(__u8*)((ptr)+6)<<48) | (((__u64)*(__u8*)((ptr)+5)<<40) | (((__u64)*(__u8*)((ptr)+4)<<32) | ((__u32)*(__u8*)((ptr)+3)<<24)|((__u32)*(__u8*)((ptr)+2)<<16) | ((__u16)*(__u8*)((ptr)+1)<<8) | *(__u8*)(ptr))
+  #define LD_UINT64_LO(ptr)	(__u64)((((__u64)*(__u8*)((ptr)+7)<<56) | ((__u64)*(__u8*)((ptr)+6)<<48) | ((__u64)*(__u8*)((ptr)+5)<<40) | ((__u64)*(__u8*)((ptr)+4)<<32) | ((__u32)*(__u8*)((ptr)+3)<<24) | ((__u32)*(__u8*)((ptr)+2)<<16) | ((__u16)*(__u8*)((ptr)+1)<<8) | *(__u8*)(ptr)))
  #endif
  #ifndef ST_UINT64_LO
   #define ST_UINT64_LO(ptr,val)	*(__u8*)(ptr)=(__u8)(val); *(__u8*)((ptr)+1)=(__u8)((UINT16)(val)>>8); *(__u8*)((ptr)+2)=(__u8)((__u32)(val)>>16); *(__u8*)((ptr)+3)=(__u8)((__u32)(val)>>24); *(__u8*)((ptr)+4)=(__u8)((__u64)(val)>>32); *(__u8*)((ptr)+5)=(__u8)((__u64)(val)>>40); *(__u8*)((ptr)+6)=(__u8)((__u64)(val)>>48); *(__u8*)((ptr)+7)=(__u8)((__u64)(val)>>56)
@@ -349,14 +369,14 @@ void ST_FLOAT_SWAP(void *b, float f);
 #endif
 
 
-/* Use byte-by-byte access to structures */
+	/* Use byte-by-byte access to structures */
 #define LD_UINT16(ptr)		LD_UINT16_LO(ptr)
 #define LD_UINT32(ptr)		LD_UINT32_LO(ptr)
 #define ST_UINT16(ptr,val)	ST_UINT16_LO(ptr,val)
 #define ST_UINT32(ptr,val)	ST_UINT32_LO(ptr,val)
 #if defined(__u64_defined)
-#define LD_UINT64(ptr)		LD_UINT64_LO(ptr)
-#define ST_UINT64(ptr,val)	ST_UINT64_LO(ptr,val)
+ #define LD_UINT64(ptr)		LD_UINT64_LO(ptr)
+ #define ST_UINT64(ptr,val)	ST_UINT64_LO(ptr,val)
 #endif
 
 
