@@ -437,7 +437,7 @@ return(loaded);
 }
 
 
-int savestruct(FILE *F,const char *description, ...)
+int savestruct(FILE *F, const char *description, ...)
 {
  va_list ap;
  int writed=0;
@@ -447,6 +447,7 @@ int savestruct(FILE *F,const char *description, ...)
 
  while(*description!=0)
    {
+   //printf("%c",*description);fflush(stdout);
    switch(*description)
      {     
 #ifndef __Ellipsis_Expand_Short
@@ -454,39 +455,44 @@ int savestruct(FILE *F,const char *description, ...)
      case 'B':{const char c = va_arg(ap,char);
 	      writed+=fwrite(&c,1,1,F);}
               break;	
-     case 'w':writed += WrWORD_LoEnd(va_arg(ap,WORD),F);	          
+     case 'w':writed += WrWORD_LoEnd(va_arg(ap,WORD),F);
      	      break;
      case 'W':writed+=WrWORD_HiEnd(va_arg(ap,WORD),F);
      	      break;
 #else	//all shorts are internally converted to int
      case 'b':
      case 'B':{char c=va_arg(ap,int);
-	      writed+=fwrite(&c,1,1,F);	      
+               writed+=fwrite(&c,1,1,F);
               break;}
-     case 'w':writed+=WrWORD_LoEnd( va_arg(ap,int),F);
+     case 'w':writed += WrWORD_LoEnd(va_arg(ap,int),F);
      	      break;
-     case 'W':writed+=WrWORD_HiEnd( va_arg(ap,int),F);
+     case 'W':writed += WrWORD_HiEnd(va_arg(ap,int),F);
      	      break;
 #endif
-     case 'd':writed+=WrDWORD_LoEnd( va_arg(ap,DWORD),F);
+     case 'd':writed += WrDWORD_LoEnd(va_arg(ap,DWORD),F);
      	      break;
-     case 'D':writed+=WrDWORD_HiEnd( va_arg(ap,DWORD),F);
+     case 'D':writed += WrDWORD_HiEnd( va_arg(ap,DWORD),F);
      	      break;
 
      case 'a':
      case 'A':ArraySize=0;
-     	      while (isdigit(*(++description)))
-	         {
+              while (isdigit(*(++description)))
+                 {
                  ArraySize=10*ArraySize + (int)(*description-'0');
                  }
               description--;
-
-              writed+=fwrite(va_arg(ap,char *),1,ArraySize,F);
+              writed += fwrite(va_arg(ap,const char *), 1, ArraySize,F);
               break;
-     case 'q':writed+=WrQWORD_LoEnd(va_arg(ap,QWORD_),F);	      
+     case 'q':writed+=WrQWORD_LoEnd(va_arg(ap,QWORD),F);
      	      break;
      case 'Q':writed+=WrQWORD_HiEnd(va_arg(ap,QWORD_),F);
      	      break;
+     case 'e':{const double e = va_arg(ap,double);
+              writed+=WrQWORD_LoEnd(*(const QWORD*)&e,F);}
+     	      break;
+     case 'E':{const double e = va_arg(ap,double);
+              writed+=WrQWORD_HiEnd(*(const QWORD*)&e,F);}
+     	      break;
 
      default:printf("Error: Unknown character %c !", *description);
      }
