@@ -261,7 +261,7 @@ FILE *F;
    {
      fclose(F);
      printf("Old file \"%s\" exists!\n", str());
-     remove(str());
+     remove(str());		// Erase old file.
    }
  }
 }
@@ -626,10 +626,10 @@ string FileName;
  fprintf(F,"/*Do not edit this file, it is generated automatically from .enc files*/\n");
 
 
- BuildTranslator(cpwp4a,internal,F);
- BuildTranslator(cpwp5,internal,F);
- BuildTranslator(cpwp5_cz,internal,F);
- BuildTranslator(cpwp6,internal,F);
+ BuildTranslator(cpwp4a,internal,F);	cpwp4a.Erase();
+ BuildTranslator(cpwp5,internal,F);	cpwp5.Erase();
+ BuildTranslator(cpwp5_cz,internal,F);	cpwp5_cz.Erase();
+ BuildTranslator(cpwp6,internal,F);	cpwp6.Erase();
 
 //if(heapcheck()<=0)
 //	asm int 3;
@@ -665,6 +665,7 @@ WriteTranslator(cp1250,cpkam,trn,F);
  fprintf(F,"/*Do not edit this file. It is automatically generated.*/\n");
  BuildTranslator(cphtml,internal,F);
  WriteStringTable(F,cphtml,llHTML);
+ cphtml.Erase();
  if(FcloseEpilog(F,FileName(),"html.trn")) return -1;
 
 
@@ -675,28 +676,29 @@ WriteTranslator(cp1250,cpkam,trn,F);
    return -2;
  }
  fprintf(F,"/*Do not edit this file. It is automatically generated.*/\n");
- BuildTranslator(cpkam,internal,F);
+ BuildTranslator(cpkam,internal,F);		cpkam.Erase();
 
- BuildTranslator(iso_8859_1,internal,F);
- BuildTranslator(iso_8859_2,internal,F);
- BuildTranslator(iso_8859_3,internal,F);
- BuildTranslator(iso_8859_4,internal,F);
+ BuildTranslator(iso_8859_1,internal,F);	iso_8859_1.Erase();
+ BuildTranslator(iso_8859_2,internal,F);	iso_8859_2.Erase();
+ BuildTranslator(iso_8859_3,internal,F);	iso_8859_3.Erase();
+ BuildTranslator(iso_8859_4,internal,F);	iso_8859_4.Erase();
 
- BuildTranslator(cp852,internal,F);
- BuildTranslator(cp1250,internal,F);
- BuildTranslator(cp1251,internal,F);
- BuildTranslator(cp1252,internal,F);
- BuildTranslator(cp1253,internal,F);
- BuildTranslator(cp1254,internal,F);
- BuildTranslator(cp1255,internal,F);
- BuildTranslator(unicode,internal,F);
- BuildTranslator(koi8cs,internal,F);
- BuildTranslator(koi8r,internal,F);
+ BuildTranslator(cp852,internal,F);		cp852.Erase();
+ BuildTranslator(cp1250,internal,F);		cp1250.Erase();
+ BuildTranslator(cp1251,internal,F);		cp1251.Erase();
+ BuildTranslator(cp1252,internal,F);		cp1252.Erase();
+ BuildTranslator(cp1253,internal,F);		cp1253.Erase();
+ BuildTranslator(cp1254,internal,F);		cp1254.Erase();
+ BuildTranslator(cp1255,internal,F);		cp1255.Erase();
+ BuildTranslator(cp1276,internal,F);		// no erase, will be needed
+ BuildTranslator(koi8cs,internal,F);		koi8cs.Erase();
+ BuildTranslator(koi8r,internal,F);		koi8r.Erase();
+ BuildTranslator(unicode,internal,F);		// no erase, will be needed
 
 	// *************** Output codepage generator *****************
- BuildTranslator(internal,unicode, F);
- BuildTranslator(internal,cp1276, F);
- BuildTranslator(internal,symbol, F);
+ BuildTranslator(internal,unicode, F);		unicode.Erase();
+ BuildTranslator(internal,cp1276, F);		cp1276.Erase();
+ BuildTranslator(internal,symbol, F);		// no erase, will be needed
 
 /*
  CreateTranslator(trn, internal, cp1250);
@@ -722,9 +724,9 @@ WriteTranslator(cp1250,cpkam,trn,F);
  }
 
  fprintf(F,"/*Do not edit this file. It is automatically generated.*/\n");
- BuildTranslator(symbol, internal, F);
- BuildTranslator(Wingdings, internal, F);
- BuildTranslator(mtef2, internal, F);
+ BuildTranslator(symbol, internal, F);		symbol.Erase();
+ BuildTranslator(Wingdings, internal, F);	Wingdings.Erase();
+ BuildTranslator(mtef2, internal, F);		mtef2.Erase();
 
  if(FcloseEpilog(F,FileName(),"mtef.trn")) return -1;
 
@@ -737,7 +739,7 @@ SkipMtef:
    return -3;
  }
  fprintf(F,"/*Do not edit this file. It is automatically generated.*/\n");
- BuildTranslator(MAC_ROMAN,internal,F);
+ BuildTranslator(MAC_ROMAN,internal,F);		MAC_ROMAN.Erase();
  if(FcloseEpilog(F,FileName(),"macroman.trn")) return -1;
 
 
