@@ -359,18 +359,15 @@ static const int nFmlTransWords = sizeof(FmlTransTable)/sizeof(FmlTransTable[0])
  * @param[out]	  BegBrace	Amount of unbalanced curly braces at the beginning. */
 static bool CheckFormula(const char *EquStr, int & Braces, int & BegBrace)
 {
-int len;
-
  BegBrace = 0;
  Braces = 0;
  if(EquStr==NULL) return(false);
- len=strlen(EquStr);
 
- while(len>0)
+ while(*EquStr != 0)
 	{
 	switch(*EquStr)
 	   {
-	   case '\\':len--;EquStr++;
+	   case '\\':if(EquStr[1]!=0) EquStr++;	// prevent to go over zero terminator.
 		     break;
            case  '{':Braces++;
            	     break;
@@ -378,7 +375,6 @@ int len;
 		     if(BegBrace>Braces) BegBrace=Braces;
                      break;
            }
-        len--;
         EquStr++;
         }
 
@@ -475,7 +471,8 @@ bool RemoveSymbol(string & str1, string & str2, const char *symbol)
 {
 const char *str, *UPStr;
 unsigned char c;
-int i, p, symlen;
+int p, symlen;
+unsigned i;
 string t;
 
   if(symbol==NULL) return false;
@@ -497,17 +494,17 @@ NewTest:
 		  }
 	 }
 
-     if( (isalpha(*(str+symlen))||isdigit(*(str+symlen))) &&
+     if((isalpha(*(str+symlen))||isdigit(*(str+symlen))) &&
 	    isalpha(*symbol) )
 		  {
 		  str=strstr(++str, symbol);
 		  goto NewTest;
 		  }
      }
-  p=-1;
+  p = -1;
   if(str!=NULL)
 	{
-	p=str-str2();
+	p = str-str2();
 	if(p<symlen) goto SkipUpcaseTest;
 	}
 
@@ -551,7 +548,7 @@ NewTest2:
 	 goto NewTest2;
 	 }
 
-  p=UPStr-t();
+  p = UPStr-t();
 
 SkipUpcaseTest:
   if (p >= 1 && (str2[p-1] == '\\' || isalpha(str2[p-1])) &&
@@ -559,7 +556,7 @@ SkipUpcaseTest:
     return false;
 
   str1 += copy(str2,0,p);
-  str2  = copy(str2,p+strlen(symbol),length(str2)-p-strlen(symbol));
+  str2  = copy(str2, p+strlen(symbol), length(str2)-strlen(symbol)-p);
   
 return true;
 }
@@ -588,7 +585,7 @@ void DeleteCurlyBraces(string & str)
   while(str[0]=='{' && str[length(str)-1]=='}')	// remove surrounding {...}
    {
    int BraceLevel=1;
-   for(int i=1; i<length(str)-2; i++)
+   for(unsigned i=1; i<length(str)-2; i++)
      {
      if(str[i]=='{') BraceLevel++;
      if(str[i]=='}') 
@@ -1090,9 +1087,9 @@ void Interpret(TconvertedPass1 *cq, string & strB, string & strE,
 	       const char *seq, const char *symbol, const string arg[])
 {
 #ifdef DEBUG
-  fprintf(cq->log,"\n#Interpret(%s,%s) ",strB(),strE());fflush(cq->log);
+  fprintf(cq->log,"\n#Interpret(%s,%s) ",chk(strB()),chk(strE()));fflush(cq->log);
 #endif
-  int j, a, a2;
+  unsigned j, a, a2;
   int p;
   string Numeral;
 
@@ -1169,14 +1166,14 @@ void Interpret(TconvertedPass1 *cq, string & strB, string & strE,
 		      if(arg[1][j] == '&') a2++;
 			if(arg[1][j] == '#')
 			  {
-			  if (a2 > a) a = a2;
+			  if(a2 > a) a = a2;
                           a2 = 0;
                           }
 			j++;
                       }
                    if(a2 > a) 	a = a2;
 
-		   for(j = 0; j <= a; j++)  strB+='c';
+		   for(j=0; j<=a; j++)  strB+='c';
                    break;
 
         case '9': if (p == 0) p = length(strB);
@@ -1479,7 +1476,7 @@ int PrimeCount = 0;
     else
        ch = strchr(ch2, '\'');
 
-    PrimeCount = 0;      
+    PrimeCount = 0;
   }
 
   return Str;
@@ -1535,7 +1532,7 @@ BYTE styles;
 
       while(RemoveSymbol(StrBeg, StrEnd, FmlTransTable[i].szWP))
 	   {
-	   //if(cq->log!=NULL) fprintf(cq->log,"\n%s |||| %s\n",StrBeg(),StrEnd()); ///<<<<<
+	   //if(cq->log!=NULL) fprintf(cq->log,"\n%s |||| %s\n",chk(StrBeg()),chk(StrEnd())); ///<<<<<
 	   if(FmlTransTable[i].styles != 0) /* check additional styles */
 		{
 		styles = FmlTransTable[i].styles;
@@ -1624,7 +1621,7 @@ BYTE styles;
   StrEnd = StrBeg + StrEnd; /* Fix double superscript/subscript */  
   StrBeg.erase();
 
-  //if(cq->log!=NULL) fprintf(cq->log,"\n%s\n",StrEnd()); ///<<<<<
+  //if(cq->log!=NULL) fprintf(cq->log,"\n%s\n",chk(StrEnd())); ///<<<<<
 
 	// Check braces \left and \right
   if(CheckFormulaLeftRight(StrEnd(),i,j))
