@@ -440,11 +440,11 @@ TImageFileHandler TIFF_H(".TIFF",
  #else
 	NULL,
  #endif
- //#if SupportWPG>=3
- //	SavePictureWPG);
- //#else
+ #if SupportWPG>=3
+ 	SavePictureWPG);
+ #else
 	NULL);
- //#endif
+ #endif
 #endif
 
 
