@@ -28,6 +28,8 @@
 #include "struct.h"
 
 
+// https://tronche.com/computer-graphics/gif/gif89a.html
+
 //--------------------------GIF---------------------------
 #ifdef SupportGIF
 
@@ -42,7 +44,7 @@ typedef struct
 typedef struct
 	{
 	WORD Left, Top, Width, Height;
-	BYTE Flag;
+	BYTE Flag;	//Local Color Table Flag 1 Bit; Interlace Flag 1 Bit; Sort Flag 1 Bit; Reserved 2 Bits; Size of Local Color Table 3 Bits
 	} TypeGIFImageDescriptor;
 
 
@@ -135,8 +137,15 @@ MustReadChunk:
      {
        RdFromFile();
      }
+#ifdef HI_ENDIAN
+     BitBuf |= ( (DWORD)(*(BYTE *)ptr) << 16 );
+     ptr++;
+     BitBuf |= ( (DWORD)(*(BYTE *)ptr) << 24 );
+     ptr++;
+#else
      BitBuf |= ( (DWORD)(*(WORD *)ptr) << 16 );
      ptr+=2;
+#endif
    }
  }
  u = BitBuf >> BitPos;
@@ -274,7 +283,6 @@ int I;
   if((OutCode=(BYTE *)malloc(4096))==NULL) goto FINISH;
   if((CompBuffer=(BYTE *)malloc(GIFBufSize))==NULL) goto FINISH;
   if((Prefix=(WORD *)calloc(4096,sizeof(WORD)))==NULL) goto FINISH;
-
   if((Suffix=(WORD *)calloc(4096,sizeof(WORD)))==NULL) goto FINISH;
 
   while(!feof(f))
@@ -288,7 +296,7 @@ int I;
        case 0x21:			   	/*?-Extended Bloks*/
 	  if(fread(OutCode,1,2,f)!=2) goto FINISH;
 	   //      WriteLn('Extension block type: ',Outcode^[0]);}
-	  CodeSize=OutCode[1];
+	  CodeSize = OutCode[1];
 	  while(CodeSize>0)
 	     {
 	     Nacteno=fread(OutCode,1,CodeSize+1,f);
@@ -297,14 +305,14 @@ int I;
 	    }
 	  break;
 
-       case 0x2C:          
+       case 0x2C:
 	  if(LoadGIFImageDescriptor(f,GIFImageDescriptor)!=9) goto FINISH;
 	  Interlace = -1;
 	  if((GIFImageDescriptor.Flag & 64)>0) Interlace=0;
 	  /*?-Image Descriptor*/
 	  //fprintf(F,"New raster W=%u, H=%u\n", GIFImageDescriptor.Width,GIFImageDescriptor.Height);
 
-	  Raster=CreateRaster2D(GIFImageDescriptor.Width,GIFImageDescriptor.Height,
+	  Raster = CreateRaster2D(GIFImageDescriptor.Width,GIFImageDescriptor.Height,
 		NearAvailPlanes((((GIFImageDescriptor.Flag & 0x80)?GIFImageDescriptor.Flag:GIFHeader.Flag) & 7) + 1));
 	  if(Raster==NULL) goto FINISH;
 
@@ -315,7 +323,7 @@ int I;
 		 if(LocalPalette==NULL) goto FINISH;
 		 if(LocalPalette->Data1D==NULL) goto FINISH;
 		 X*=3;
-		 Nacteno=fread(LocalPalette->Data1D,1,X,f);
+		 Nacteno = fread(LocalPalette->Data1D,1,X,f);
 		 if(Nacteno<X) goto FINISH;
 		 }
 
@@ -492,17 +500,17 @@ static int StoreGIFHeader(FILE *f, const Image &Img, APalette *GlobPalette=NULL)
   if(GlobPalette) NumColors = GlobPalette->Size1D;
  
   WORD GlobalColorTableSize;
-  BYTE GlobalColorTableFlag;
+  //BYTE GlobalColorTableFlag;
   if(NumColors>0)
   {
     NumColors = 1 << BitsNeeded(NumColors);
     GlobalColorTableSize = BitsNeeded(NumColors) - 1;
-    GlobalColorTableFlag = 1;
+    //GlobalColorTableFlag = 1;
   }
   else
   {
     GlobalColorTableSize = 0;
-    GlobalColorTableFlag = 0;
+    //GlobalColorTableFlag = 0;
   }
 
   BYTE Flag =  (Img.Raster->GetPlanes() << 4) |
@@ -512,10 +520,9 @@ static int StoreGIFHeader(FILE *f, const Image &Img, APalette *GlobPalette=NULL)
   {
     Flag |= 0x80;	// If set to 1, a global color table is used.
   }
-  fputc(Flag, f);
-  fputc(0, f);
-  fputc(0, f);
-
+  fputc(Flag, f);	// GCT
+  fputc(0, f);		// Background color: index
+  fputc(0, f);		// Default pixel aspect ratio.
 
   if((Flag & 0x80)>0)  	/*Global Color Map*/
   {
@@ -525,7 +532,7 @@ static int StoreGIFHeader(FILE *f, const Image &Img, APalette *GlobPalette=NULL)
     else
     {
       fwrite(GlobPalette->Data1D,3,GlobPalette->Size1D,f);
-      for(int i=GlobPalette->Size1D; i<GlobalColorTableSize; i++)
+      for(int i=GlobPalette->Size1D; i<GlobalColorTableSize; i++) // feed rest of palette with zeros.
       {
         fputc(0, f);
         fputc(0, f);
@@ -970,6 +977,7 @@ FILE *f;
 TypeGIFImageDescriptor ID;
 const Image *CurrentImage;
 APalette *GlobPalette = NULL;
+bool NeedLocalPalette = false;
 
   if(Img.Raster==NULL) return(-10);
   if(Img.Raster->GetPlanes()>8) return(-11);
@@ -981,7 +989,7 @@ APalette *GlobPalette = NULL;
     if(Img.Palette!=NULL)
     {
       GlobPalette = Img.Palette;
-      GlobPalette->UsageCount++;  
+      GlobPalette->UsageCount++;
     }
     else
     {
@@ -989,10 +997,12 @@ APalette *GlobPalette = NULL;
       if(GlobPalette)
       {
         GlobPalette->UsageCount++;
-        FillGray(GlobPalette, Img.Raster->GetPlanes());
+        FillGray(GlobPalette);
       }
     }
   }
+  else
+    NeedLocalPalette = true;
 
 	/* Write GIF signature */
   int ret = StoreGIFHeader(f,Img,GlobPalette);
@@ -1021,8 +1031,54 @@ APalette *GlobPalette = NULL;
     ID.Top = 0;
     ID.Width = CurrentImage->Raster->Size1D;
     ID.Height = CurrentImage->Raster->Size2D;
-    ID.Flag = 0;    
+    ID.Flag = 0;
+    if(NeedLocalPalette)
+    {
+      WORD NumColors = 1 << Img.Raster->GetPlanes();
+      GlobPalette = Img.Palette;
+      if(GlobPalette!=NULL)
+      {
+        GlobPalette->UsageCount++;
+      }
+      else
+      {
+        GlobPalette = BuildPalette(NumColors, 8);
+        if(GlobPalette)
+        {
+          GlobPalette->UsageCount++;
+          FillGray(GlobPalette);
+        }
+      }
+      WORD LocalColorTableSize;
+      if(NumColors>0)
+      {
+        NumColors = 1 << BitsNeeded(NumColors);
+        LocalColorTableSize = BitsNeeded(NumColors) - 1;
+      }
+      else
+        LocalColorTableSize = 0;
+      if(GlobPalette)
+          ID.Flag = 0x80 | (LocalColorTableSize & 0x7);
+    }
     SaveGIFImageDescriptor(f,ID);
+    if((ID.Flag & 0x80)>0)			/*Local Color Map*/
+    {
+      WORD LocalColorTableSize = (unsigned)2 << (ID.Flag & 7);
+      if(GlobPalette->Size1D >= LocalColorTableSize)
+        fwrite(GlobPalette->Data1D,3,LocalColorTableSize,f);
+      else
+      {
+        fwrite(GlobPalette->Data1D,3,GlobPalette->Size1D,f);
+        for(int i=GlobPalette->Size1D; i<LocalColorTableSize; i++) // feed rest of palette with zeros.
+        {
+          fputc(0, f);
+          fputc(0, f);
+          fputc(0, f);
+        }
+      }
+      if(GlobPalette->UsageCount-- <= 1) delete GlobPalette;
+      GlobPalette = NULL;
+    }
 
     WbitStream GIF_Writer(f,CurrentImage->Raster);
     GIF_Writer.codesize = CurrentImage->Raster->GetPlanes();
@@ -1032,7 +1088,7 @@ APalette *GlobPalette = NULL;
     GIF_Writer.LZW_Compress();
 
 	/* Write terminating 0-byte */
-    fputc(0,f);        
+    fputc(0,f);
 
     CurrentImage = CurrentImage->Next;
   } while(CurrentImage != NULL);
