@@ -11,6 +11,14 @@
 #include "imgsupp.h"
 
 
+#define MaxTextExtent 256
+
+#ifndef MIN
+ #define MIN(a,b) ((a)<(b) ? (a) : (b))
+#endif
+
+
+
 ///// JPG Reader /////
 
 #if defined(SupportJPG) && SupportJPG>0
@@ -24,6 +32,9 @@ extern "C" {
 #include "raster.h"
 
 
+const char ExifPreffix[6] = {'E','x','i','f', '\0', '\0'};
+
+
 struct my_error_mgr {
   struct jpeg_error_mgr pub;	/* "public" fields */
 
@@ -49,9 +60,123 @@ METHODDEF(void) my_error_exit (j_common_ptr cinfo)
 }
 
 
-
 #if SupportJPG>=4 || SupportJPG==2
 
+static const char xmp_std_header[]="http://ns.adobe.com/xap/1.0/";
+
+static int GetCharacter(j_decompress_ptr jpeg_info)
+{
+  if (jpeg_info->src->bytes_in_buffer == 0)
+    if ((!((*jpeg_info->src->fill_input_buffer)(jpeg_info))) ||
+        (jpeg_info->src->bytes_in_buffer == 0))
+      return EOF;
+  jpeg_info->src->bytes_in_buffer--;
+  return(GETJOCTET(*jpeg_info->src->next_input_byte++));
+}
+
+
+static inline int GetProfileLength(j_decompress_ptr jpeg_info)
+{
+  const int _c = GetCharacter(jpeg_info);
+  if((_c != EOF) && (_c >= 0))
+  {
+    const int _c2 = GetCharacter(jpeg_info);
+    if((_c2 != EOF) && (_c2 >= 0))
+        return _c * 256 + _c2;
+  }
+  return 0;
+}
+
+
+static boolean ReadGenericProfile(j_decompress_ptr jpeg_info)
+{
+  size_t header_length=0, length;
+  register size_t i;
+  string profile_name;
+  unsigned char *profile;
+  int c, marker;
+
+  if(jpeg_info->client_data==NULL) return TRUE;
+  Image *Img = (Image *)jpeg_info->client_data;
+
+	/* Determine length of generic profile. */
+  length = GetProfileLength(jpeg_info);
+  if(length <= 2) return TRUE;
+  length -= 2;
+
+  /*
+    jpeg_info->unread_marker ('int') is either zero or the code of a
+    JPEG marker that has been read from the data source, but has not
+    yet been processed.  The underlying type for a marker appears to
+    be UINT8 (JPEG_COM, or JPEG_APP0+n).
+
+    Unexpected markers are prevented due to registering for specific
+    markers we are interested in via jpeg_set_marker_processor().
+
+    #define JPEG_APP0 0xE0
+    #define JPEG_COM 0xFE
+
+    #define ICC_MARKER  (JPEG_APP0+2)
+    #define IPTC_MARKER  (JPEG_APP0+13)
+    #define XML_MARKER  (JPEG_APP0+1)
+   */
+  marker = jpeg_info->unread_marker - JPEG_APP0;
+
+	/* Compute generic profile name. */
+  profile_name.printf("APP%d",marker);
+//  FormatString(profile_name,"APP%d",marker);
+
+	/* Obtain Image.*/
+//  client_data=(MagickClientData *) jpeg_info->client_data;
+
+	/* Copy profile from JPEG to allocated memory. */
+//  profile = client_data->buffer;
+
+  if(length < 6) return TRUE;
+  for(i=0 ; i<6 ; i++)
+  {
+    c = GetCharacter(jpeg_info);
+    if(c==EOF) return TRUE;
+    if(c!=ExifPreffix[i]) return TRUE;
+  }
+
+  if(marker != 1)  return TRUE;
+
+  length -= 6;
+
+  PropertyItem *PropExif = new PropertyItem;
+  PropExif->Data = (unsigned char *)malloc(length);
+  if(PropExif->Data==NULL) return TRUE;
+  PropExif->DataSize = length;
+
+  for(i=0 ; i < length ; i++)
+  {
+    c = GetCharacter(jpeg_info);
+    if(c==EOF)
+    {
+      delete PropExif;
+      return TRUE;
+    }
+    ((char*)PropExif->Data)[i] = c;
+  }
+  PropExif->Name = ExifPreffix;
+  Img->AttachProperty(PropExif);
+
+/*
+  else if(((marker == 1) && (length > strlen(xmp_std_header)+1)) &&
+           (memcmp(profile, xmp_std_header, strlen(xmp_std_header)+1) == 0))
+  {
+	// XMP is required to fit in one 64KB chunk.  Strip off its JPEG namespace header.
+     header_length = strlen(xmp_std_header)+1;
+     //FormatString((char *) profile_name,"XMP");
+  }
+*/
+
+  //if(profile) free(profile);
+  return  TRUE;
+}
+
+
 Raster2DAbstract *LoadFragmentJPG(FILE *F)
 {
 struct jpeg_decompress_struct cinfo;
@@ -59,6 +184,7 @@ struct my_error_mgr jerr;
 int row_stride;		/* physical row width in output buffer */
 JSAMPARRAY buffer;	/* Output row buffer */
 unsigned current_line = 0;
+//int i;
 
   if(F==NULL) return NULL;
 
@@ -78,8 +204,13 @@ unsigned current_line = 0;
 	/* Step 2: specify data source (eg, a file) */
   jpeg_stdio_src(&cinfo, F);
 
-	/* Step 3: read file parameters with jpeg_read_header() */
+/*
+  for (i=1; i < 16; i++)
+    if ((i != 2) && (i != 13) && (i != 14))
+      jpeg_set_marker_processor(&cinfo,JPEG_APP0+i,ReadGenericProfile);
+*/
 
+	/* Step 3: read file parameters with jpeg_read_header() */
   (void) jpeg_read_header(&cinfo, TRUE);
   /* We can ignore the return value from jpeg_read_header since
    *   (a) suspension is not possible with the stdio data source, and
@@ -109,8 +240,6 @@ unsigned current_line = 0;
     
     int line_size = 3 * cinfo.output_width;	    /* Assume put_scanline_someplace wants a pointer and sample count. */
 
-    //{     BlockWrite(outfile, buffer^, row_stride);}
-
     if(line_size > row_stride) line_size = row_stride;
 
     if(current_line < Raster->Size2D)
@@ -150,6 +279,7 @@ struct my_error_mgr jerr;
 FILE * infile;		/* source file */
 JSAMPARRAY buffer;	/* Output row buffer */
 int row_stride;		/* physical row width in output buffer */
+int i;
 
   /* In this example we want to open the input file before doing anything else,
    * so that the setjmp() error recovery below can assume the file is open.
@@ -180,6 +310,12 @@ int row_stride;		/* physical row width in output buffer */
   /* Step 2: specify data source (eg, a file) */
   jpeg_stdio_src(&cinfo, infile);
 
+  for (i=1; i < 16; i++)
+    if ((i != 2) && (i != 13) && (i != 14))
+      jpeg_set_marker_processor(&cinfo,JPEG_APP0+i,ReadGenericProfile);
+
+  cinfo.client_data = &Img;
+
   /* Step 3: read file parameters with jpeg_read_header() */
 
   (void) jpeg_read_header(&cinfo, TRUE);
@@ -260,7 +396,7 @@ ENDPROC:
   /* At this point you may want to check to see whether any corrupt-data
    * warnings occurred (test whether jerr.pub.num_warnings is nonzero). */
 
-  Img.AttachRaster(Raster);  
+  Img.AttachRaster(Raster);
   return(Img);  /* And we're done! */
 }
 #endif
@@ -336,6 +472,28 @@ int row_stride;		 /* physical row width in image buffer */
    */
   jpeg_start_compress(&cinfo, TRUE);
 
+  if(!Img.Properties.isEmpty())
+  {
+    for(int i=0; i<Img.Properties.PropCount; i++)
+    {
+      PropertyItem *Prop = Img.Properties.pProperties[i];
+      if(Prop!=NULL && Prop->Data!=NULL && Prop->DataSize>0 && Prop->Name=="Exif")
+      {
+        int j;
+		// First chunk is scattered into 2 pieces.
+        jpeg_write_m_header(&cinfo, JPEG_APP0+1, (int)MIN(Prop->DataSize+6,65533L));
+        for(j=0; j<6; j++) jpeg_write_m_byte (&cinfo, ExifPreffix[j]);
+        for(j=0; j<(int)MIN(Prop->DataSize,65533L-6); j++)
+          jpeg_write_m_byte (&cinfo, ((unsigned char*)Prop->Data)[j]);
+        while(j<Prop->DataSize)
+        {
+          jpeg_write_marker(&cinfo, JPEG_APP0+1, (unsigned char*)Prop->Data+j, (int)MIN(Prop->DataSize-j,65533L));
+          j += 65533L;
+        }
+      }
+    }
+  }
+
   /* Step 5: while (scan lines remain to be written) */
   /*           jpeg_write_scanlines(...); */
 
