@@ -3,7 +3,7 @@
  * function:    Miscellaneous utilities for manipulation with images.         *
  * modul:       rasterut.cc                                                   *
  * licency:     GPL or LGPL                                                   *
- * Copyright: (c) 1998-2022 Jaroslav Fojtik                                   *
+ * Copyright: (c) 1998-2023 Jaroslav Fojtik                                   *
  ******************************************************************************/
 #include<stdio.h>
 #include<string.h>
@@ -61,12 +61,81 @@ void Flip2(BYTE *b, unsigned len)
   
   while(x1<x2)
   {
-    BYTE tmp = GetValue2(b,x1);    
+    BYTE tmp = GetValue2(b,x1);
     SetValue2(b, x1, GetValue2(b,x2));
     SetValue2(b, x2, tmp);
     x1++;
     x2--;
-  }  
+  }
+}
+
+
+/* ------------ Properties ---------------*/
+
+PropertyItem::~PropertyItem()
+{
+  if(Data)
+  {
+    free(Data);
+    Data=NULL;DataSize=0;
+  }
+}
+
+
+PropertyList::~PropertyList()
+{
+  if(pProperties != NULL)
+  {
+    for(int i=0; i<PropCount; i++)
+    {
+      if(pProperties[i] != NULL)
+      {
+        if(pProperties[i]->UsageCount--<=1) delete pProperties[i];
+        pProperties[i] = NULL;
+      }
+    }
+    free(pProperties);
+    pProperties = NULL;
+  }
+}
+
+
+void PropertyList::AddProp(PropertyItem *NewProp)
+{
+int i;
+  if(NewProp==NULL) return;
+	// Method 1: list ie empty.
+  if(pProperties == NULL)
+  {
+    pProperties = (PropertyItem**)malloc(sizeof(PropertyItem*));
+    if(pProperties==NULL)
+    {	// report memory error
+      return;
+    }
+    pProperties[0] = NewProp;
+    PropCount=1;
+    NewProp->UsageCount++;
+    return;
+  }
+	// Method 2: list has a free slot.
+  for(i=0; i<PropCount; i++)
+  {
+    if(pProperties[i]==NULL)
+    {
+      pProperties[i] = NewProp;
+      NewProp->UsageCount++;
+      return;
+    }
+  }
+	// Method 3: list must be reallocated.
+  PropertyItem **NewList = (PropertyItem**)realloc(pProperties, sizeof(PropertyItem*)*(PropCount+1));
+  if(NewList==NULL)
+  {
+    return;
+  }
+  pProperties = NewList;
+  pProperties[PropCount++] = NewProp;
+  NewProp->UsageCount++;
 }
 
 
@@ -75,7 +144,7 @@ void Image::Create(unsigned SizeX, unsigned SizeY, int Planes)
 {
   if(Raster)
     {
-    if(Raster->GetSize1D()==SizeX && Raster->Size2D==SizeY && 
+    if(Raster->GetSize1D()==SizeX && Raster->Size2D==SizeY &&
        Raster->GetPlanes()==(Planes & 0xFF) && 
        Raster->UsageCount==1)		// only this object owns raster
 		return;
@@ -101,6 +170,13 @@ Image::Image(const Image & I, bool AllFrames)
  if((Raster=I.Raster)!=NULL) Raster->UsageCount++;
  if((Palette=I.Palette)!=NULL) Palette->UsageCount++;
  if((VecImage=I.VecImage)!=NULL) VecImage->UsageCount++;
+
+ if(!I.Properties.isEmpty())
+ {
+    for(int i=0; i<I.Properties.PropCount; i++)
+      Properties.AddProp(I.Properties.pProperties[i]);
+ }
+
  x=I.x; y=I.y; dx=I.dx; dy=I.dy; RotAngle=I.RotAngle;
  Next = NULL;  
 
@@ -119,6 +195,7 @@ Image::Image(const Image & I, bool AllFrames)
  }
 }
 
+
 Raster2DAbstract *Image::operator=(Raster2DAbstract *NewRaster)
 {
  x=y=dx=dy=0; 
@@ -128,6 +205,7 @@ Raster2DAbstract *Image::operator=(Raster2DAbstract *NewRaster)
  return(Raster);
 }
 
+
 Image &Image::operator=(const Image &I)
 {
 Image *PImg;
@@ -153,6 +231,11 @@ CopyImg:if((PImg->Raster=CurrImg->Raster)!=NULL)
 	PImg->RotAngle=CurrImg->RotAngle;
         if((PImg->VecImage=CurrImg->VecImage)!=NULL)
                 CurrImg->VecImage->UsageCount++;
+        if(!CurrImg->Properties.isEmpty())
+	  {
+          for(int i=0; i<CurrImg->Properties.PropCount; i++)
+            PImg->Properties.AddProp(CurrImg->Properties.pProperties[i]);
+          }
 	CurrImg = CurrImg->Next;
 	}
  return(*this);
@@ -178,7 +261,7 @@ Image *I,*OldI;
       }
    if(I->VecImage!=NULL)
       {
-      if(I->VecImage->UsageCount--<=1) delete I->VecImage;      
+      if(I->VecImage->UsageCount--<=1) delete I->VecImage;
       I->VecImage = NULL;
       }
    OldI = I;
@@ -272,14 +355,20 @@ void Image::AttachVecImg(VectorImage *NewVecImg)
 {
   if(VecImage==NewVecImg) return;		// Raster is already attached
   if(VecImage!=NULL)			// Detach previously attached raster
-   {
-   if(VecImage->UsageCount--<=1) delete VecImage;
-   VecImage = NULL;
-   }
+  {
+    if(VecImage->UsageCount--<=1) delete VecImage;
+    VecImage = NULL;
+  }
   if(NewVecImg!=NULL)			// Attach raster now
-   {
-   VecImage=NewVecImg; VecImage->UsageCount++;
-   }
+  {
+    VecImage=NewVecImg; VecImage->UsageCount++;
+  }
+}
+
+
+void Image::AttachProperty(PropertyItem *NewProp)
+{
+  Properties.AddProp(NewProp);
 }
 
 
