@@ -3,7 +3,7 @@
  * function:    Object set for handling vector images.                        *
  * modul:       vec_image.cc                                                  *
  * licency:     GPL or LGPL                                                   *
- * Copyright: (c) 2018-2022 Jaroslav Fojtik                                   *
+ * Copyright: (c) 2018-2023 Jaroslav Fojtik                                   *
  ******************************************************************************/
 #include <stdlib.h>
 #include <stdio.h>
@@ -41,7 +41,7 @@ float SinAlpha = sin(alpha);
     {
       const float k = Raster->Size1D / (float)Raster->Size2D;
       dx2 = sqrt(0.5) / (1+k) * TrDx;
-      dy2 = k * sqrt(0.5) / (1+k) * TrDx;      
+      dy2 = k * sqrt(0.5) / (1+k) * TrDx;
     }
   }
   else
@@ -169,12 +169,14 @@ void DumpRaster2File(FILE *f, Raster2DAbstract *Raster, APalette *Palette,
 		float CenterX, float CenterY,
 		float dx, float dy, float RotAngle, int ColorMode)
 {
-int X,Y;
+unsigned X, Y;
 RGBQuad RGB;
+char RasterPlanes;
 
   if(f==NULL || Raster==NULL ||
      Raster->Size1D<=0 || Raster->Size2D<=0) return;
 
+  RasterPlanes = labs(Raster->GetPlanes());
   if(ColorMode==ImagePalette)
     if(Palette->GetPlanes()<=8*Palette->Channels())
 	ColorMode=12;
@@ -206,7 +208,7 @@ RGBQuad RGB;
       "/rgbindx 0 def\n",
           (ColorMode==ImagePalette || ColorMode==12)
 	    ? Raster->GetSize1D()
-	    : (Raster->GetSize1D()*Raster->GetPlanes()+7)/8,
+	    : (Raster->GetSize1D()*RasterPlanes+7)/8,
           Raster->GetSize1D());
 
    fputs("\ngsave", f);
@@ -237,8 +239,8 @@ RGBQuad RGB;
    if((ColorMode==ImagePalette || ColorMode==12)) Y=8;
    else
    {
-     Y = Raster->GetPlanes()/Raster->Channels();
-     if(Y>=16) Y=8;      
+     Y = RasterPlanes/Raster->Channels();
+     if(Y>=16) Y=8;
    }
    fprintf(f,
      "%% dimensions of data\n"
@@ -260,7 +262,7 @@ RGBQuad RGB;
       (ColorMode>ImageGray)?"false 3 color":"" );
      }
 
-   int BytesPerLine = ((long)(Raster->GetPlanes())*Raster->GetSize1D()+7) / 8;
+   unsigned BytesPerLine = (((unsigned long)RasterPlanes)*Raster->GetSize1D()+7) / 8;
 
      // When negative size is given, flip raster data
    if(dy < 0) Flip2D(Raster);
@@ -295,13 +297,13 @@ RGBQuad RGB;
 	      CharsOnLine = 0;
 	      }
 	    CharsOnLine += 2;
-	    fprintf(f,"%.2X", RasLine->GetValue1D(X));	    
+	    fprintf(f,"%.2X", RasLine->GetValue1D(X));
 	    }
 	  break;
 	  }
     case ImagePalette:
 	  {
-	  if(Raster->GetPlanes()==8)  //speedup trick for 8 planes
+	  if(RasterPlanes==8)  //speedup trick for 8 planes
 	    {
 	    BYTE *ptrb = (BYTE *)Raster->GetRow(Y);
 	    for(X=0; X<BytesPerLine; X++)
@@ -327,7 +329,7 @@ RGBQuad RGB;
 	}
 
    case ImageTrueColor:
-	   if(Raster->GetPlanes()==24) goto FAST_COPY;
+	   if(RasterPlanes==24) goto FAST_COPY;
 	   {
 	     Raster1DAbstract *RasLine = Raster->GetRowRaster(Y);	  
 	     if(RasLine)
@@ -337,16 +339,16 @@ RGBQuad RGB;
 		 {
 	         w = RasLine->GetValue1D(X);	      
 	         fprintf(f,"%.2X%.2X%.2X", w&0xFF, (w>>8)&0xFF, (w>>16)&0xFF);
-	         }               
+	         }
                }
            }
 	   break;
 
    default:
      {
-	if(Raster->GetPlanes()==8 ||
-	   Raster->GetPlanes()==4 ||
-	   Raster->GetPlanes()==1)	//speedup trick for 8, 4 and 1 planes
+	if(RasterPlanes==8 ||
+	   RasterPlanes==4 ||
+	   RasterPlanes==1)	//speedup trick for 8, 4 and 1 planes
 	 {
 FAST_COPY:BYTE *ptrb = (BYTE *)Raster->GetRow(Y);
 	 for(X=0; X<BytesPerLine; X++)
@@ -359,7 +361,7 @@ FAST_COPY:BYTE *ptrb = (BYTE *)Raster->GetRow(Y);
 	 Raster1DAbstract *RasLine = Raster->GetRowRaster(Y);	  
 	 if(RasLine)
 	   {
-	   int k = Raster->GetPlanes()-8;
+	   int k = RasterPlanes - 8;
 	   DWORD w;
 	   for(X=0;X<RasLine->GetSize1D();X++)
 	   {
