@@ -44,7 +44,7 @@ void CrackObject(TconvertedPass1 *cq, DWORD end_of_code)
 FILE *txt;
 unsigned short i,y;
 long pos;
-unsigned short len;
+DWORD len;
 static char ss[13] = "00__Hack.txt";
 char c;
 
@@ -1488,7 +1488,7 @@ void Language(TconvertedPass1 *cq, WORD WPx_Language)
 #ifdef DEBUG
   fprintf(cq->log,"\n#Language(%d) ",WPx_Language);fflush(cq->log);
 #endif
-char CurLang[3],OldLang[3];
+char CurLang[3], OldLang[3];
 const char *LangStr;
 int i;
 
