@@ -21,7 +21,7 @@
 #include "images/img_futi.h"
 
 
-#define T602Version "0.05"
+#define T602Version "0.06"
 
 
 class TconvertedPass1_602: public TconvertedPass1
@@ -71,7 +71,7 @@ FFormatTranslator Format602("T602",Factory_602);
 void TconvertedPass1_602::ChangeEncoding(void)
 {
 #ifdef DEBUG
-  fprintf(cq->log,"\n#ChangeEncoding() ");fflush(cq->log);
+  fprintf(log,"\n#ChangeEncoding() ");fflush(log);
 #endif
 long value;
 string translator;
@@ -174,7 +174,7 @@ void TconvertedPass1_602::HeaderFooter602(const string &args, char He_Fo)
 void TconvertedPass1_602::Image602(void)
 {
 #ifdef DEBUG
-  fprintf(cq->log,"\n#TconvertedPass1_602::Image602() ");fflush(cq->log);
+  fprintf(log,"\n#TconvertedPass1_602::Image602() ");fflush(log);
 #endif
 TBox Box;
 char *str,ch;
