@@ -747,7 +747,7 @@ DWORD fsize;
   TablePos=0;
 
   DocumentStart=ftell(wpd);
-  fsize=filesize(wpd);
+  fsize = FileSize(wpd);
   perc.Init(ftell(wpd), fsize,_("First pass Abiword:") );
 
   ActualPos = ftell(wpd);
