@@ -908,7 +908,7 @@ DWORD fsize;
 
   TablePos=0;
 
-  fsize = filesize(wpd);
+  fsize = FileSize(wpd);
   perc.Init(ftell(wpd), fsize,_("First pass HTML:") );
 
   ActualPos = ftell(wpd);
