@@ -1177,7 +1177,7 @@ bool Line=false;
 
   DocumentStart=ftell(wpd);
 
-  fsize=filesize(wpd);
+  fsize = FileSize(wpd);
   perc.Init(ftell(wpd), fsize,_("First pass MTEF:") );
 
   MTEF_Version=fgetc(wpd);
