@@ -2018,7 +2018,7 @@ DWORD fsize;
   nomore_valid_tabs = false;
 
 
-  fsize=filesize(wpd);
+  fsize = FileSize(wpd);
   perc.Init(ftell(wpd), fsize,_("First pass RTF:") );
 
   rownum = 0;
@@ -2062,7 +2062,7 @@ DWORD WChar;
 
  cq->ConvertCpg=GetTranslator("unicodeTOinternal");
 
- fsize=filesize(cq->wpd);
+ fsize = FileSize(cq->wpd);
  cq->ActualPos = ftell(cq->wpd);
  cq->perc.Init(cq->ActualPos, fsize, MESSAGE);
 
