@@ -1374,7 +1374,8 @@ DWORD begincp, endcp;
 				  &cq->clx, cq->bteChpx, cq->posChpx,
 				  cq->char_intervals, cq->wpd);
 	    if(cq->log)
-		fprintf(cq->log,_("\nChar begins at %lXh ends %lXh, pos is %lXh "), cq->char_fcFirst, cq->char_fcLim, (unsigned long)cq->ActualPos);
+		fprintf(cq->log,_("\nChar begins at %lXh ends %lXh, pos is %lXh "), 
+					(unsigned long)cq->char_fcFirst, (unsigned long)cq->char_fcLim, (unsigned long)cq->ActualPos);
 	    if (0 == cq->char_pendingclose)
 		{  /* if there's no character run open, but there should be then I believe that the fcFirst search
 		      has failed me, so I set it to now. I need to investigate this further. */
