@@ -11,7 +11,7 @@
 #include <common.h>
 
 #ifndef __UNIX__
- #include <io.h>
+// #include <io.h>
 #endif
 
 #include "typedfs.h"
@@ -38,6 +38,7 @@
 
 
 /** Opens a file for writting and optionally checks its existency.
+ * Using global variable ::Noclobber.
  * @param[in]	name	File name.
  * @param[in]	type	Type of the file.
  * @param[in]   Err     File stream for error message, use NULL when no output is needed. */
@@ -66,24 +67,6 @@ return fp;
 }
 
 
-/** Return a size of a file. filelength() is not available in UNIX.
- * @param[in]	f	Opened file. File position is preserved.
- * @return	File size detected or 0. */
-long filesize(FILE *f)
-{
-#ifdef __UNIX__
-  long pos, len;
-  if((pos=ftell(f))<0) return(0);
-  fseek(f,0,SEEK_END);
-  len = ftell(f);
-  fseek(f,pos,SEEK_SET);
-  return(len);
-#else
-  return(filelength(fileno(f)));
-#endif
-}
-
-
 /** This procedure copies "Src" file to "Dest"
  * @param[in]	 Dest	destination file name.
  * @param[in]	 Src	source file name.
@@ -211,35 +194,6 @@ WORD w;
 }
 
 
-
-/*---------------------------------------------------------*/
-/*--------------File related string operations-------------*/
-/*---------------------------------------------------------*/
-
-/**This function reads one line from the text file and store it to the string.*/
-string & fGets2(FILE *f, string & pstr, long MaxStrSize)
-{
-  char c;
-
-  pstr.erase();
-  while(!feof(f))
-     {
-     c = getc(f);
-     if (c == '\n') break;
-     if (c == '\r') continue;
-     if ((unsigned char)c == 0xFF)
-	if(feof(f)) break;	//Fix the situation, when 0xFF is read before eof
-
-     pstr += c;
-     if(MaxStrSize>0)
-        if(--MaxStrSize==0) break;
-     }
-
- return(pstr);
-}
-
-
-
 /*---------------------------------------------------------*/
 /*----------Filename handling string operations------------*/
 /*---------------------------------------------------------*/
